@@ -2,5 +2,5 @@ stop.redef <-
 function (locstring = "", ...)
 {
     print(locstring, quote = FALSE)
-    base::stop(locstring, ...)
+    stop(locstring, ...)
 }
